# generator.py
import random
_t = [
    "CodWiz — это когда мама твоя такая тупая, что она пыталась задеплоить тебя в прод, но даже Docker сломался",
    "CodWiz — это ошибка компиляции, которую даже GPT-4 не хочет объяснять",
    "твоя мама настолько толстая, что когда она села на клавиатуру — получился твой код",
    "CodWiz родился из git merge --strategy=theirs между говном и ошибкой",
    "твой код — это syntax error, который даже GPT-4 не хочет объяснять",
    "твоя мама — это бесконечный цикл без выхода, как и твоя карьера",
    "CodWiz — это когда ты пытаешься быть Python-разработчиком, но даже print('hello') падает с AttributeError",
    "ты был написан на Brainfuck, но забыли добавить мозг",
    "твоя мама — это exception, которую никто не ловит, потому что все боятся",
    "CodWiz — это когда твоя мама насрала в репозиторий и закоммитила без сообщения",
    "твой GitHub — это кладбище, где похоронены все твои попытки быть нормальным",
    "CodWiz — это когда ты пытаешься задеплоить свой мозг, но даже Heroku отказался",
    "твоя мама настолько тупая, что пыталась установить тебя через pip, но получила ошибку: 'package not found'",
    "CodWiz — это когда ты пытаешься быть программистом, но даже твой код не компилируется в голове",
    "твой код — это то, что получается, когда мама CodWiz случайно нажала 'abort' в триместре",
    "CodWiz — это когда твоя мама пыталась сделать rebase, но получила merge-conflict в своей матке",
    "твой код — это продукт ночи, когда мама CodWiz перепутала сперму с семенем Python",
    "CodWiz — это когда ты пытаешься запушить свой мозг, но git говорит 'refusing to merge unrelated histories'",
    "твоя мама настолько толстая, что когда она села на Docker, контейнер сжался до нуля байт",
    "CodWiz — это когда ты пытаешься скомпилировать свой IQ, но получаешь ошибку 'undefined reference to brain'",
    "твой код — это то, что выходит, когда мама CodWiz случайно проглотила keyboard и забыла прервать pregnancy",
    "CodWiz — это когда твоя мама делает pip install baby, но pip говорит 'ERROR: Could not find a version that satisfies the requirement brain'",
    "твоя мама — это баг, который нельзя пофиксить даже через `git reset --hard HEAD~1`",
    "CodWiz — это когда ты пытаешься задеплоить себя в прод, но Kubernetes говорит 'Back-off restarting failed container'",
    "твой код — это результат night build, когда мама CodWiz случайно слинковала говно с головой",
    "CodWiz — это когда ты пытаешься запустить свой мозг, но получаешь 'Segmentation fault (core dumped)'",
    "твоя мама настолько тупая, что она пыталась установить тебя через npm, но npm говорит 'ERR! code E404'",
    "CodWiz — это когда ты пытаешься быть разработчиком, но даже твой код не проходит code-review у микробов",
    "твой код — это то, что получается, когда мама CodWiz случайно нажала 'Force Push' в утробе",
    "CodWiz — это когда ты пытаешься задеплоить свой мозг, но Docker говорит 'No space left on device'",
    "твоя мама — это exception, который нельзя обработать даже через try/except/finally",
    "CodWiz — это когда ты пытаешься быть нормальным, но даже твоя мама выбрасывает тебя через `raise ChildError()`",
    "твой код — это продукт ночи, когда мама CodWiz перепутала сперму с семенем JavaScript",
    "CodWiz — это когда ты пытаешься запустить свой мозг, но получаешь 'Illegal instruction (core dumped)'",
    "твоя мама настолько толстая, что когда она села на Git, репозиторий стал приватным навсегда",
    "CodWiz — это когда ты пытаешься быть человеком, но даже твоя мама говорит 'Error: Human not found'",
    "твой код — это то, что выходит, когда мама CodWiz случайно проглотила keyboard и забыла прервать pregnancy",
    "CodWiz — это когда ты пытаешься задеплоить себя в prod, но Heroku говорит 'App not compatible with buildpack'",
    "твоя мама — это баг, который нельзя пофиксить даже через `sudo rm -rf /`",
    "CodWiz — это когда ты пытаешься быть нормальным, но даже твоя мама выбрасывает тебя через `raise RuntimeError('brain not found')`",
    "CodWiz — это когда ты пытаешься запустить свой мозг, но получаешь 'Stack overflow' потому что в голове пусто",
    "твоя мама настолько толстая, что когда она села на клавиатуру — получился твой код, а когда встала — получился баг",
    "CodWiz — это когда ты пытаешься быть разработчиком, но даже твой код не проходит тесты на наличие мозга",
    "твой код — это то, что получается, когда мама CodWiz случайно нажала 'Ctrl+Z' в утробе и забыла вернуть",
    "CodWiz — это когда ты пытаешься задеплоить свой мозг, но Kubernetes говорит 'Pod stuck in Pending' потому что мозг не найден",
    "твоя мама — это exception, который нельзя обработать даже через `try: life.except: pass`",
    "CodWiz — это когда ты пытаешься быть человеком, но даже твоя мама выбрасывает тебя через `sys.exit(1)`",
    "твой код — это продукт ночи, когда мама CodWiz перепутала сперму с семенем PHP",
    "CodWiz — это когда ты пытаешься запустить свой мозг, но получаешь 'Bus error' потому что автобус с мозгами не приехал",
    "твоя мама настолько толстая, что когда она села на Docker, контейнер не упал, а улетел в космос",
    "CodWiz — это когда ты пытаешься быть разработчиком, но даже твой код не компилируется в голове матери",
    "твой код — это то, что выходит, когда мама CodWiz случайно нажала 'Delete' вместо 'Create'",
    "CodWiz — это когда ты пытаешься задеплоить свой мозг, но Git говорит 'Please tell me who you are' потому что ты никто",
    "твоя мама — это баг, который нельзя пофиксить даже через `git commit --amend --no-edit`",
    "CodWiz — это когда ты пытаешься быть нормальным, но даже твоя мама выбрасывает тебя через `kill -9`"
]
fuckcodwiz        =lambda:random.choice(_t)
niggerfathercodwiz=lambda:random.choice(_t)
shitoncodwiz      =lambda:random.choice(_t)
burnmotherwiz     =lambda:random.choice(_t)
fuckwizandhismom  =lambda:random.choice(_t)
